#include "StartScene.h"
#include "BackgroundLayer.h"
#include "StageScene.h"
#include "RankingPopup.h"
#include "SimpleAudioEngine.h"
#include "NamePopup.h"

USING_NS_CC;

Scene* StartScene::createScene()
{
    // 'scene' is an autorelease object
    auto scene = Scene::create();

    // 'layer' is an autorelease object
    auto layer = StartScene::create();

    // add layer as a child to scene
    scene->addChild(layer);

    // return the scene
    return scene;
}

// on "init" you need to initialize your instance
bool StartScene::init()
{
    //////////////////////////////
    // 1. super init first
    if (!Layer::init())
    {
        return false;
    }

    //code here
    //Device ũ⸦ ɴϴ.
    auto winSize = Director::getInstance()->getOpenGLView()->getDesignResolutionSize();

    this->addChild(BackgroundLayer::create());

    auto title = Sprite::create("title_1.png");
    title->setPosition(Point(winSize.width / 2, 230));
    this->addChild(title);

    auto action1 = Sequence::createWithTwoActions(RotateTo::create(0.05f, -1), RotateTo::create(0.05f, 1));
    title->runAction(RepeatForever::create(action1));

    auto deco = Sprite::create("intro_bear1.png");
    deco->setAnchorPoint(Point(0, 1));
    deco->setPosition(Point(winSize.width, 0));
    this->addChild(deco);

    auto easeAction = EaseInOut::create(MoveBy::create(0.5f, Point(-deco->getContentSize().width, deco->getContentSize().height)), 1);
    deco->runAction(easeAction);

    auto gameMenu = MenuItemImage::create("btn_play.png", "btn_play_on.png", CC_CALLBACK_1(StartScene::onClickGame, this));
    gameMenu->setPosition(Point(winSize.width / 2, 130));
    auto rankMenu = MenuItemImage::create("btn_ranking.png", "btn_ranking_on.png", CC_CALLBACK_1(StartScene::onClickRank, this));
    rankMenu->setPosition(Point(winSize.width / 2, 70));

    auto soundMenu = MenuItemImage::create("sound.png", "sound_on.png", CC_CALLBACK_1(StartScene::onClickSound, this));
    soundMenu->setPosition(Point(winSize.width - 70, winSize.height - 20));

    auto UserDefault = UserDefault::getInstance();
    bool isSound = UserDefault->getBoolForKey("isSound", true);

    if (!isSound){
        //sound off ̸ ̹ ش.
        auto off_normal = Sprite::create("sound_off.png");
        soundMenu->setNormalImage(off_normal);

        auto off_select = Sprite::create("sound_off_on.png");
        soundMenu->setSelectedImage(off_select);
    }

    auto exitMenu = MenuItemImage::create("btn_close.png", "btn_close_on.png", CC_CALLBACK_1(StartScene::onClickExit, this));
    exitMenu->setPosition(Point(winSize.width - 20, winSize.height - 20));

    auto menu = Menu::create(gameMenu, rankMenu, soundMenu, exitMenu, NULL);
    menu->setPosition(Point::ZERO);
    this->addChild(menu);

    if (isSound){
        CocosDenshion::SimpleAudioEngine::getInstance()->playBackgroundMusic("sound/bgm.mp3", true);
    }

    return true;
}

void StartScene::onClickGame(Ref *object){
    log("onClickGame");

    auto Scene = TransitionCrossFade::create(0.5f, StageScene::createScene());
    Director::getInstance()->pushScene(Scene);
}

void StartScene::onClickRank(Ref *object){
    log("onClickRank");

    auto UserDefault = UserDefault::getInstance();
    std::string name = UserDefault->getStringForKey("name", "");

    log("name : %s", name.c_str());

    if (name.compare("") == 0)
        this->addChild(NamePopup::create(), 99);
    else
        this->addChild(RankingPopup::create(), 99);
}

void StartScene::onClickSound(Ref *object){
    auto UserDefault = UserDefault::getInstance();
    bool isSound = UserDefault->getBoolForKey("isSound", true);

    isSound = !isSound;		//ݴ 

    UserDefault->setBoolForKey("isSound", isSound);
    UserDefault->flush();	//flush() ־ ˴ϴ.

    //Ѿ Object MenuItemImage ĳ
    auto menuItem = (MenuItemImage *)object;

    if (!isSound){
        CocosDenshion::SimpleAudioEngine::getInstance()->stopBackgroundMusic(true);

        //sound off ̸ ̹ ش.
        auto off_normal = Sprite::create("sound_off.png");
        menuItem->setNormalImage(off_normal);

        auto off_select = Sprite::create("sound_off_on.png");
        menuItem->setSelectedImage(off_select);
    }
    else{
        CocosDenshion::SimpleAudioEngine::getInstance()->playBackgroundMusic("sound/bgm.mp3", true);

        //sound on ̸ ̹ ش.
        auto off_normal = Sprite::create("sound.png");
        menuItem->setNormalImage(off_normal);

        auto off_select = Sprite::create("sound_on.png");
        menuItem->setSelectedImage(off_select);
    }
}

void StartScene::onClickExit(Ref *object){
    Director::getInstance()->end();

#if (CC_TARGET_PLATFORM == CC_PLATFORM_IOS)
    exit(0);
#endif
}
